==> slices_cli-0.1.23-py3-none-any.whl: slices_cli/auth.py <==
"""Slices CLI authentication."""

from typing import Annotated

import typer
from requests.exceptions import HTTPError
from rich import print

from .config import auth_file_location, delete_auth_token, parse_auth_token, save_auth_token
from .context import Context
from .oauth2.flow import AuthenticationFlow, DeviceFlow

auth_app = typer.Typer(help="User authentication", no_args_is_help=True)


@auth_app.command(help="Authenticate and retrieve credentials")
def login(
    ctx: Context,
    open_browser: Annotated[bool, typer.Option(help="Automatically open browser to perform login.")] = False,
):
    """Authenticate and retrieve credentials."""

    if not open_browser:
        flow = DeviceFlow()
        token = flow.perform_login_flow()
    else:
        flow = AuthenticationFlow()
        token = flow.perform_login_flow()

    if token:
        save_auth_token(token)

        auth_info = parse_auth_token(token)
        print(f"[bold green]Successfully logged in as '{auth_info['preferred_username']}' ")
        print(f":floppy_disk: Saved to {auth_file_location}")

        if ctx.obj.get_current_project_id() is None:
            print(
                ":backhand_index_pointing_right: "
                "Now select the project that you want to use with [blue]slices project use <project name>[/]"
            )

    else:
        print("[red]Logging in failed. :x:")


@auth_app.command(help="Show user credentials.")
def show(
    ctx: Context,
):
    """Show user credentials."""
    user_info = ctx.obj.user_info

    if user_info:
        print(f"Logged in as '{user_info['preferred_username']}'")
    else:
        print("[red]Not logged in. :x:")
        raise typer.Exit


@auth_app.command(help="Remove user credentials")
def logout():
    """Remove user credentials."""
    delete_auth_token()
    print("[bold green]Successfully logged out.[/] :white_check_mark:")
    print(f":floppy_disk: Deleted {auth_file_location}")


@auth_app.command(help="Get credentials for a specific audience.", hidden=True)
def get_for_audience(
    ctx: Context,
    audience: str,
):
    """Show user credentials."""
    user_info = ctx.obj.user_info

    if not user_info:
        print("[red]Not logged in. :x:")
        raise typer.Exit(1)
    try:
        print(ctx.obj.api.get_access_token_for_audience(audience, ctx.obj.require_project_id()))
    except HTTPError as e:
        try:
            error_response = e.response.json()
            print(f"[bold red]Error: Could not get token. :x:[/]\n[red]{error_response['error_description']}")
        except:  # noqa: E722
            print("[bold red]Error: Could not get token. :x:")
            print(f"[red]{str(e.response.text)}")
        raise typer.Exit(1) from None

==> slices_cli-0.1.29-py3-none-any.whl: slices_cli/auth.py <==
"""Slices CLI authentication."""

from typing import Annotated

import typer
from requests.exceptions import HTTPError
from rich import print

from .config import auth_file_location, delete_auth_token, parse_auth_token, save_auth_token, set_config_string
from .context import Context
from .oauth2.flow import AuthenticationFlow, DeviceFlow

auth_app = typer.Typer(help="User authentication", no_args_is_help=True)


@auth_app.command(help="Authenticate and retrieve credentials")
def login(
    ctx: Context,
    open_browser: Annotated[bool, typer.Option(help="Automatically open browser to perform login.")] = False,
):
    """Authenticate and retrieve credentials."""

    if not open_browser:
        flow = DeviceFlow()
        token = flow.perform_login_flow()
    else:
        flow = AuthenticationFlow()
        token = flow.perform_login_flow()

    if token:
        save_auth_token(token)

        auth_info = parse_auth_token(token)
        print(f"[bold green]Successfully logged in as '{auth_info['preferred_username']}' ")
        print(f":floppy_disk: Saved to {auth_file_location}")

        if ctx.obj.get_current_project_id() is None:
            print(
                ":backhand_index_pointing_right: "
                "Now select the project that you want to use with [blue]slices project use <project name>[/]"
            )

    else:
        print("[red]Logging in failed. :x:")


@auth_app.command(help="Show user credentials.")
def show(
    ctx: Context,
):
    """Show user credentials."""
    user_info = ctx.obj.user_info

    if user_info:
        print(f"Logged in as '{user_info['preferred_username']}'")
    else:
        print("[red]Not logged in. :x:")
        raise typer.Exit


@auth_app.command(help="Remove user credentials")
def logout():
    """Remove user credentials."""
    delete_auth_token()
    set_config_string("default", None, "project")
    print("[bold green]Successfully logged out.[/] :white_check_mark:")
    print(f":floppy_disk: Deleted {auth_file_location}")


@auth_app.command(help="Get credentials for a specific audience.", hidden=True)
def get_for_audience(
    ctx: Context,
    audience: str,
):
    """Show user credentials."""
    user_info = ctx.obj.user_info

    if not user_info:
        print("[red]Not logged in. :x:")
        raise typer.Exit(1)
    try:
        print(ctx.obj.api.get_access_token_for_audience(audience, ctx.obj.require_project_id()))
    except HTTPError as e:
        try:
            error_response = e.response.json()
            print(f"[bold red]Error: Could not get token. :x:[/]\n[red]{error_response['error_description']}")
        except:  # noqa: E722
            print("[bold red]Error: Could not get token. :x:")
            print(f"[red]{str(e.response.text)}")
        raise typer.Exit(1) from None
